from __future__ import annotations


path_examples = {
    "single": {"summary": "Single control", "value": "digital_gain/red"},
    "group": {"summary": "Group control", "value": "color_conversion"},
    "nested_group": {
        "summary": "Nested group control",
        "value": "color_conversion/ccm",
    },
    "nested_group_sub": {
        "summary": "Nested array control",
        "value": "color_conversion/ccm/offset",
    },
    "all_groups": {
        "summary": "All control groups",
        "value": "root",
    },
}
list_controls_responses = {
    200: {
        "description": "Success",
        "content": {
            "application/json": {
                "examples": {
                    "default": {
                        "summary": "Current default controls",
                        "value": [
                            {
                                "name": "digital_gain",
                                "children": ["red", "green", "blue"],
                            },
                            {
                                "name": "gain_map",
                                "children": ["enable", "scale", "offset", "map"],
                            },
                            {
                                "name": "color_conversion",
                                "children": [
                                    "enable",
                                    "saturation_value",
                                    {"name": "ccm", "children": ["matrix", "offset"]},
                                ],
                            },
                            {
                                "name": "lut",
                                "children": [
                                    "mono",
                                    {
                                        "name": "rgb",
                                        "children": ["red", "green", "blue"],
                                    },
                                ],
                            },
                            {"name": "flip", "children": ["horizontal", "vertical"]},
                            {"name": "binning", "children": ["horizontal", "vertical"]},
                            "pattern_generator",
                            {"name": "capture_options", "children": ["exposure_time"]},
                        ],
                    }
                },
            }
        },
    },
}
controls_info_responses = {
    200: {
        "description": "Success",
        "content": {
            "application/json": {
                "examples": {
                    "single": {
                        "summary": "Single control",
                        "value": {
                            "name": "red",
                            "path": "/digital_gain/red",
                            "description": "",
                            "format": {
                                "type": "FloatFormatter",
                                "range": {
                                    "min": 0,
                                    "max": 3.99993896484375,
                                    "step": 0.00006103515625,
                                },
                            },
                        },
                    },
                    "group": {
                        "summary": "Group control",
                        "value": {
                            "name": "color_conversion",
                            "path": "/color_conversion",
                            "description": "Color Conversion Controls",
                            "children": [
                                {
                                    "name": "enable",
                                    "path": "/color_conversion/enable",
                                    "description": "",
                                    "format": {
                                        "type": "BoolFormatter",
                                        "range": [0, 1],
                                    },
                                },
                                {
                                    "name": "saturation_value",
                                    "path": "/color_conversion/saturation_value",
                                    "description": "",
                                    "format": {
                                        "type": "IntFormatter",
                                        "range": {"min": 0, "max": 4096, "step": 1},
                                    },
                                },
                                {
                                    "name": "ccm",
                                    "path": "/color_conversion/ccm",
                                    "description": "Affine color conversion transform.",
                                    "children": [
                                        {
                                            "name": "matrix",
                                            "path": "/color_conversion/ccm/matrix",
                                            "description": "Linear color transformation using the RGBA format.",
                                            "format": {
                                                "type": "FloatFormatter",
                                                "range": {
                                                    "min": -4,
                                                    "max": 3.9998779296875,
                                                    "step": 0.0001220703125,
                                                },
                                            },
                                        },
                                        {
                                            "name": "offset",
                                            "path": "/color_conversion/ccm/offset",
                                            "description": "Color translation.",
                                            "format": {
                                                "type": "FloatFormatter",
                                                "range": {
                                                    "min": -0.5,
                                                    "max": 0.499755859375,
                                                    "step": 0.000244140625,
                                                },
                                            },
                                        },
                                    ],
                                },
                            ],
                        },
                    },
                    "nested_group": {
                        "summary": "Nested group",
                        "value": {
                            "name": "ccm",
                            "path": "/color_conversionccm",
                            "description": "Affine color conversion transform.",
                            "children": [
                                {
                                    "name": "matrix",
                                    "path": "/color_conversion/ccm/matrix",
                                    "description": "Linear color transformation using the RGBA format.",
                                    "format": {
                                        "type": "FloatFormatter",
                                        "range": {
                                            "min": -4,
                                            "max": 3.9998779296875,
                                            "step": 0.0001220703125,
                                        },
                                    },
                                },
                                {
                                    "name": "offset",
                                    "path": "/color_conversion/ccm/offset",
                                    "description": "Color translation.",
                                    "format": {
                                        "type": "FloatFormatter",
                                        "range": {
                                            "min": -0.5,
                                            "max": 0.499755859375,
                                            "step": 0.000244140625,
                                        },
                                    },
                                },
                            ],
                        },
                    },
                    "nested_array_control": {
                        "summary": "Nested array control",
                        "value": {
                            "name": "offset",
                            "path": "/color_conversion/ccm/offset",
                            "description": "Color translation.",
                            "format": {
                                "type": "FloatFormatter",
                                "range": {
                                    "min": -0.5,
                                    "max": 0.499755859375,
                                    "step": 0.000244140625,
                                },
                            },
                        },
                    },
                },
            }
        },
    },
}
control_value_examples = {
    "red_gain": {
        "summary": "Digital gain red",
        "description": "Return value for the path `digital_gain/red`.",
        "value": 1.0,
    },
    "ccm": {
        "summary": "Color conversion group",
        "description": """Return value for the path `color_conversion`. Note that the matrix `ccm` is merged together from its two sub-controls. See the next example for a possible return value.""",
        "value": {
            "enable": False,
            "saturation_value": 4095,
            "ccm": [
                [1, 0, 0, 0, 0],
                [0, 1, 0, 0, 0],
                [0, 0, 1, 0, 0],
                [0, 0, 0, 1, 0],
            ],
        },
    },
    "ccm_offset": {
        "summary": "Color conversion offset vector",
        "description": "Return the value for the offset vector with path `color_conversion/ccm/offset`",
        "value": [[0], [0], [0], [0]],
    },
}
read_control_responses = {
    200: {
        "description": "Success",
        "content": {
            "application/json": {
                "examples": control_value_examples,
            }
        },
    },
}
