"""REST API crop interface

:Authors:
    Marianna Smidth Buschle <msb@qtec.com>
"""

from typing import List

from fastapi import APIRouter
from fastapi import Depends

from quark_backend.api.common import V4L2_ROUTE
from quark_backend.api.common import CommonParams
from quark_backend.api.common import Tags
from quark_backend.api.common import V4L2Endpoints
from quark_backend.api.common import check_exceptions
from quark_backend.quark_camera import Camera
from quark_backend.quark_camera import CropRect


router = APIRouter(
    prefix=V4L2_ROUTE + V4L2Endpoints.crop,
    tags=[Tags.frame_parameters],
)


@router.get("/")
def get_crop(params: CommonParams = Depends()) -> list[CropRect]:  # noqa: B008
    """Get camera cropping rectangle(s)"""
    return check_exceptions(Camera.get_crop, params.dev)


@router.get("/bounds")
def get_crop_bounds(params: CommonParams = Depends()) -> CropRect:  # noqa: B008
    """Get camera cropping bounding rectangle"""
    return check_exceptions(Camera.get_crop_bounds, params.dev)


@router.get("/default")
def get_crop_default(params: CommonParams = Depends()) -> CropRect:  # noqa: B008
    """Get camera cropping default rectangle"""
    return check_exceptions(Camera.get_crop_def, params.dev)


@router.post("/")
def set_crop(
    rects: List[CropRect],
    params: CommonParams = Depends(),  # noqa: B008
) -> list[CropRect]:
    """Set camera cropping rectangle(s)"""
    return check_exceptions(Camera.set_crop, rects, params.dev)
