"""REST API pixel format interface

:Authors:
    Marianna Smidth Buschle <msb@qtec.com>
"""

from typing import List

from fastapi import APIRouter
from fastapi import Depends

from quark_backend.api.common import V4L2_ROUTE
from quark_backend.api.common import CommonParams
from quark_backend.api.common import Tags
from quark_backend.api.common import V4L2Endpoints
from quark_backend.api.common import check_exceptions
from quark_backend.quark_camera import Camera
from quark_backend.quark_camera import ImageFormat
from quark_backend.quark_camera import PixelFormat
from quark_backend.quark_camera import SinglePlaneFmt


router = APIRouter(
    prefix=V4L2_ROUTE + V4L2Endpoints.pixel_format,
    tags=[Tags.frame_parameters],
)


@router.get(
    "/",
    response_model=SinglePlaneFmt,
)
def get_pixel_format(params: CommonParams = Depends()) -> SinglePlaneFmt:  # noqa: B008
    """Get camera pixel format"""
    return check_exceptions(Camera.get_pixel_format, params.dev)


@router.get(
    "/list",
    response_model=List[ImageFormat],
)
def list_pixel_formats(
    params: CommonParams = Depends(),
) -> list[ImageFormat]:  # noqa: B008
    """List all possible pixel formats for this camera"""
    return check_exceptions(Camera.list_pixel_formats, params.dev)


@router.post(
    "/",
    response_model=SinglePlaneFmt,
)
def set_pixel_format(
    val: PixelFormat,
    params: CommonParams = Depends(),  # noqa: B008
) -> SinglePlaneFmt:
    """Set camera pixel format"""
    return check_exceptions(Camera.set_pixel_format, val.pixelformat, params.dev)
