"""REST API frame resolution interface

:Authors:
    Marianna Smidth Buschle <msb@qtec.com>
"""

from typing import List

from fastapi import APIRouter
from fastapi import Depends

from quark_backend.api.common import V4L2_ROUTE
from quark_backend.api.common import APIInputError
from quark_backend.api.common import CommonParams
from quark_backend.api.common import Tags
from quark_backend.api.common import V4L2Endpoints
from quark_backend.api.common import check_exceptions
from quark_backend.quark_camera import Camera
from quark_backend.quark_camera import CropRect
from quark_backend.quark_camera import FrameResolution


router = APIRouter(
    prefix=V4L2_ROUTE + V4L2Endpoints.resolution,
    tags=[Tags.frame_parameters],
)


@router.get(
    "/",
    response_model=FrameResolution,
)
def get_resolution(params: CommonParams = Depends()) -> FrameResolution:  # noqa: B008
    """Get camera resolution"""
    return check_exceptions(Camera.get_resolution, params.dev)


@router.post(
    "/",
    response_model=List[CropRect],
)
def set_resolution(
    resolution: FrameResolution,
    params: CommonParams = Depends(),  # noqa: B008
) -> FrameResolution:
    """
    Set camera resolution

    Auto-centers the cropping rectangle
    """
    if resolution.width is None and resolution.height is None:
        raise APIInputError("'width' or 'height' are required")
    return check_exceptions(
        Camera.set_resolution, resolution.width, resolution.height, params.dev
    )
